==> ejc-probuilddiary-impl-3.0.0-20220916.034313-3-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonDetailEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-施工内容（施工员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_detail")
public class PersonDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="construct_id")
    private Long constructId; // 施工区域id
    @TableField(value="construct_name")
    private String constructName; // 施工区域名称
    @TableField(value="construct_code")
    private String constructCode; // 施工区域编码
    @TableField(value="team_id")
    private Long teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="team_code")
    private String teamCode; // 班组编码
    @TableField(value="work_num")
    private Integer workNum; // 工作人数
    @TableField(value="work_memo")
    private String workMemo; // 工作情况
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getConstructCode() {
        return constructCode;
    }

    public void setConstructCode(String constructCode) {
        this.constructCode = constructCode;
    }
    public Long getTeamId() {
        return teamId;
    }

    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }
    public Integer getWorkNum() {
        return workNum;
    }

    public void setWorkNum(Integer workNum) {
        this.workNum = workNum;
    }
    public String getWorkMemo() {
        return workMemo;
    }

    public void setWorkMemo(String workMemo) {
        this.workMemo = workMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.070702-9-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonDetailEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-施工内容（施工员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_detail")
public class PersonDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="construct_id")
    private Long constructId; // 施工区域id
    @TableField(value="construct_name")
    private String constructName; // 施工区域名称
    @TableField(value="construct_code")
    private String constructCode; // 施工区域编码
    @TableField(value="team_id")
    private Long teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="team_code")
    private String teamCode; // 班组编码
    @TableField(value="work_num")
    private Integer workNum; // 工作人数
    @TableField(value="work_memo")
    private String workMemo; // 工作情况
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getConstructCode() {
        return constructCode;
    }

    public void setConstructCode(String constructCode) {
        this.constructCode = constructCode;
    }
    public Long getTeamId() {
        return teamId;
    }

    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }
    public Integer getWorkNum() {
        return workNum;
    }

    public void setWorkNum(Integer workNum) {
        this.workNum = workNum;
    }
    public String getWorkMemo() {
        return workMemo;
    }

    public void setWorkMemo(String workMemo) {
        this.workMemo = workMemo;
    }
    
}
